@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "slideview" "0.6.1"
+(define-package "slideview" "20250121.324"
   "File slideshow."
-  ()
-  :url "https://github.com/mhayashi1120/Emacs-slideview/raw/master/slideview.el"
-  :commit "ec2340e7b0e74201206d14e3eaef1e77149f122d"
-  :revdesc "ec2340e7b0e7"
+  '((emacs "25.1"))
+  :url "https://github.com/mhayashi1120/Emacs-slideview"
+  :commit "4d7c8b91d339126b4c5a6365362aadb90ee0e7f9"
+  :revdesc "4d7c8b91d339"
   :keywords '("files")
   :authors '(("Masahiro Hayashi" . "mhayashi1120@gmail.com"))
   :maintainers '(("Masahiro Hayashi" . "mhayashi1120@gmail.com")))
